pub struct insertAuthenticatorCall {
pub leafIndex: u64,
pub newAuthenticatorAddress: Address,
pub pubkeyId: u32,
pub newAuthenticatorPubkey: U256,
pub oldOffchainSignerCommitment: U256,
pub newOffchainSignerCommitment: U256,
pub signature: Bytes,
pub nonce: U256,
}Expand description
Function with signature insertAuthenticator(uint64,address,uint32,uint256,uint256,uint256,bytes,uint256) and selector 0x2c92b8a5.
function insertAuthenticator(uint64 leafIndex, address newAuthenticatorAddress, uint32 pubkeyId, uint256 newAuthenticatorPubkey, uint256 oldOffchainSignerCommitment, uint256 newOffchainSignerCommitment, bytes memory signature, uint256 nonce) external;Fields
leafIndex: u64newAuthenticatorAddress: AddresspubkeyId: u32newAuthenticatorPubkey: U256oldOffchainSignerCommitment: U256newOffchainSignerCommitment: U256signature: Bytesnonce: U256Trait Implementations
Sourceimpl Clone for insertAuthenticatorCall
impl Clone for insertAuthenticatorCall
Sourcefn clone(&self) -> insertAuthenticatorCall
fn clone(&self) -> insertAuthenticatorCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for insertAuthenticatorCall
impl SolCall for insertAuthenticatorCall
Sourceconst SIGNATURE: &'static str = "insertAuthenticator(uint64,address,uint32,uint256,uint256,uint256,bytes,uint256)"
const SIGNATURE: &'static str = "insertAuthenticator(uint64,address,uint32,uint256,uint256,uint256,bytes,uint256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Address, Uint<32>, Uint<256>, Uint<256>, Uint<256>, Bytes, Uint<256>)
type Parameters<'a> = (Uint<64>, Address, Uint<32>, Uint<256>, Uint<256>, Uint<256>, Bytes, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<insertAuthenticatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<insertAuthenticatorCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = insertAuthenticatorReturn
type Return = insertAuthenticatorReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<insertAuthenticatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<insertAuthenticatorCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.