ProtocolSigner

Trait ProtocolSigner 

pub trait ProtocolSigner {
    // Required method
    fn sign(&self, message: FieldElement) -> EdDSASignature
       where Self: Sized + Send + Sync;
}
Enables entities that sign messages within the Protocol for use with the ZK circuits.

This is in particular used by Authenticators to authorize requests for nullifier generation.

Required Methods

fn sign(&self, message: FieldElement) -> EdDSASignature
where Self: Sized + Send + Sync,

Signs a message with the protocol signer using the EdDSA scheme (off-chain signer), for use with the Protocol ZK circuits.

Implementors