pub trait ProtocolSigner {
// Required method
fn sign(&self, message: FieldElement) -> EdDSASignature
where Self: Sized + Send + Sync;
}Expand description
Enables entities that sign messages within the Protocol for use with the ZK circuits.
This is in particular used by Authenticators to authorize requests for nullifier generation.
Required Methods
Sourcefn sign(&self, message: FieldElement) -> EdDSASignature
fn sign(&self, message: FieldElement) -> EdDSASignature
Signs a message with the protocol signer using the EdDSA scheme (off-chain signer), for use
with the Protocol ZK circuits.